@@ -58,9 +58,9 @@ post '/login' => sub {
 
     if ($success) {
         my $user = schema('netdisco')->resultset('User')
-          ->find( param('username') );
+          ->find({ username => { -ilike => param('username') } });
 
-        session logged_in_user => param('username');
+        session logged_in_user => $user->username;
         session logged_in_fullname => $user->fullname;
         session logged_in_user_realm => $realm;
 
